@@ -172,6 +172,19 @@ class TestViews(UnicoreTestCase):
         [linked_page] = response['linked_pages']
         self.assertEqual(linked_page.get_object(), page1)
 
+    def test_content_linked_pages_none(self):
+        [category] = self.create_categories(self.workspace, count=1)
+        [page1] = self.create_pages(
+            self.workspace,
+            linked_pages=None,
+            count=1, content='', description='',
+            primary_category=category.uuid)
+        request = testing.DummyRequest()
+        request.matchdict['uuid'] = page1.uuid
+        self.views = CmsViews(request)
+        response = self.views.content()
+        self.assertEqual(list(response['linked_pages']), [])
+
     def test_content_markdown_rendering(self):
         [category] = self.create_categories(self.workspace, count=1)
         [page] = self.create_pages(
